@@ -97,6 +97,11 @@ public:
 	 */
 	IPV4Validator() { };
 
+	/**
+	 * keeps compilers happy.
+	 */
+	virtual ~IPV4Validator() {};
+
 	/**
 	 * Pure virtual application operator. Apply the validation
 	 * algorithm specific to derived classes.  
@@ -121,6 +126,11 @@ public:
 	 */
 	IPV4MulticastValidator(){};
 
+	/**
+	 * Keeps compilers happy.
+	 */
+	virtual ~IPV4MulticastValidator(){};
+
 	/**
 	 * Application operator. Apply the validation algorithm
 	 * specific to multicast addresses
@@ -500,6 +510,11 @@ public:
 	 */
 	IPV6Validator() { };
 
+	/**
+	 * Keeps compilers happy.
+	 */
+	virtual ~IPV6Validator() {};
+
 	/**
 	 * Pure virtual application operator. Apply the validation
 	 * algorithm specific to derived classes.  
@@ -524,6 +539,11 @@ public:
 	 */
 	IPV6MulticastValidator(){};
 
+	/**
+	 * Keeps compilers happy...
+	 */
+	virtual ~IPV6MulticastValidator(){};
+
 	/**
 	 * Application operator. Apply the validation algorithm
 	 * specific to multicast addresses
