@@ -346,7 +346,7 @@ protected:
 class __EXPORT Keydata : protected MemPager
 {
 public:
-#if defined(__GNUC__) || !defined(__hpux)
+#ifdef	CCXX_PACKED
 #pragma pack(1)
 #endif
 
@@ -371,7 +371,7 @@ public:
 		char *value;
 	};
 
-#if defined(__GNUC__) || !defined(__hpux)
+#ifdef	CCXX_PACKED
 #pragma pack()
 #endif
 
